Over-sampling methods — Version 0.9.0.dev0

# Over-sampling methods

The `imblearn.over_sampling` provides a set of method to perform over-sampling.

## Basic over-sampling

`RandomOverSampler`(*[, sampling_strategy, …]) | Class to perform random over-sampling.

## SMOTE algorithms

`SMOTE`(*[, sampling_strategy, random_state, …]) | Class to perform over-sampling using SMOTE.
`SMOTENC`(categorical_features, *[, …]) | Synthetic Minority Over-sampling Technique for Nominal and Continuous.
`SMOTEN`(*[, sampling_strategy, random_state, …]) | Synthetic Minority Over-sampling Technique for Nominal.
`ADASYN`(*[, sampling_strategy, random_state, …]) | Oversample using Adaptive Synthetic (ADASYN) algorithm.
`BorderlineSMOTE`(*[, sampling_strategy, …]) | Over-sampling using Borderline SMOTE.
`KMeansSMOTE`(*[, sampling_strategy, …]) | Apply a KMeans clustering before to over-sample using SMOTE.
`SVMSMOTE`(*[, sampling_strategy, …]) | Over-sampling using SVM-SMOTE.

TomekLinks RandomOverSampler